package guanlixitong

import (
	"shylinux.com/x/ice"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/community/src/gonganxitong"
	"shylinux.com/x/enterprise/src/guanlixitong/model"
)

type Table struct {
	gonganxitong.Table
	list string `name:"list group_uid uid auto" role:"void"`
}

func (s Table) Inputs(m *ice.Message, arg ...string) {
	switch arg[0] {
	case model.USER_GROUP_ROLE:
		s.InputsListRole(m, UserGroupRoleList)
	case model.GROUP_TYPE:
		s.InputsList(m, GroupTypeList)
	case model.COMPANY_UID:
		m.Cmdy(Company{}, s.Select).Cut(model.UID, model.NAME).RenameAppend(model.UID, arg[0])
		m.DisplayInputKeyNameIconTitle()
	default:
		s.Table.Inputs(m, arg...)
	}
}
func (s Table) RewriteAppend(m *ice.Message, arg ...string) *ice.Message {
	m.RewriteAppend(func(value, key string, index int) string {
		kit.If(key == model.GROUP_TYPE, func() { value = GroupType(kit.Int(value)).String() })
		kit.If(key == model.USER_GROUP_ROLE, func() { value = UserGroupRole(kit.Int(value)).String() })
		return value
	})
	return s.Table.RewriteAppend(m)
}
func (s Table) SelectJoinCompany(m *ice.Message) *ice.Message {
	return s.SelectJoin(m, company{}, model.NAME, model.CITY_UID)
}
func (s Table) checkRole(m *ice.Message, arg ...UserGroupRole) bool {
	kit.If(len(arg) == 0, func() { arg = append(arg, UserGroupLeader) })
	role := UserGroupRole(kit.Int(m.Cmd(userGroup{}, s.Select, m.OptionSimple(model.GROUP_UID, model.USER_UID)).Append(model.ROLE)))
	for _, v := range append(arg, UserGroupCreator) {
		if role == v {
			return true
		}
	}
	return !m.WarnNotRight(true, role.String())
}
func (s Table) recordEvent(m *ice.Message, info string, arg ...string) *ice.Message {
	s.Table.RecordEvent(m, m.Option(model.GROUP_UID), info, kit.Select(m.Option(model.UID), arg, 0))
	return m
}

type Tables struct{ Table }

func (s Tables) BeforeMigrate(m *ice.Message, arg ...string) {}

func NewTable(userGroup gonganxitong.UserPlacer, group gonganxitong.Placer) Table {
	return Table{Table: gonganxitong.NewTable(userGroup, group, company{})}
}
